@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+from tests.test_serializer.py.SerializerJson import SerializerJson
+from tests.test_serializer.py.DeserializerJson import DeserializerJson
+
 
 def create_command_from_json(string):
     import json
@@ -7,14 +10,16 @@ def create_command_from_json(string):
     for key in dictionary:
         command = Factory.build(key)
         if command is not None:
-            command.deserialize_json(dictionary[key])
+            deserializer = DeserializerJson(dictionary[key])
+            command.deserialize_json(deserializer)
         return command
 
 def serialize_command_to_json(command):
     import json
     js = dict()
     js[command.get_type()] = dict()
-    command.serialize_json(js[command.get_type()])
+    serializer = SerializerJson(js[command.get_type()])
+    command.serialize_json(serializer)
     return json.dumps(js)
 
 def clone_object(obj):
